@@ -253,16 +253,27 @@ void PanasonicTV1::populateProtocol(
   addPanasonicKey("MULTIWINDOW", Unmapped_Key, 0x80, 0x00, 0xE6); // "multi pip"
   addPanasonicKey("FM/TV", Unmapped_Key, 0x80, 0x00, 0xEE);
   addPanasonicKey("Viera Tools", ServiceMenu_Key, 0x80, 0x00, 0xEF);
+  addPanasonicKey("Enable remote", Unmapped_Key, 0x80, 0x00, 0xFB);
+  addPanasonicKey("Disable remote", Unmapped_Key, 0x80, 0x00, 0xFC);
   addPanasonicKey("System reset", FactoryReset_Key, 0x80, 0x00, 0xFF);
 
+  addPanasonicKey("InputTv", AntennaInput_Key, 0x80, 0x02, 0x30);
+
   addPanasonicKey("Component 1", ComponentInput_Key, 0x80, 0x04, 0x7C);
   addPanasonicKey("Component 2", Component2Input_Key, 0x80, 0x04, 0x7D);
   addPanasonicKey("HDMI 1", HDMIInput_Key, 0x80, 0x04, 0xB0);
   addPanasonicKey("HDMI 2", HDMI2Input_Key, 0x80, 0x04, 0xB1);
   addPanasonicKey("HDMI 3", HDMI3Input_Key, 0x80, 0x04, 0xB2);
   addPanasonicKey("HDMI 4", HDMI4Input_Key, 0x80, 0x04, 0xB3);
+/* The discrete aspect commands are confusing:
+  addPanasonicKey("aspect - normal", Unmapped_Key, 0x80, 0x04, 0xC7);
+  addPanasonicKey("aspect - zoom", Unmapped_Key, 0x80, 0x04, 0xC9);
+  addPanasonicKey("aspect - just", Unmapped_Key, 0x80, 0x04, 0xCB);
+  addPanasonicKey("aspect - auto", Unmapped_Key, 0x80, 0x04, 0xCC);
+  addPanasonicKey("aspect - full", Unmapped_Key, 0x80, 0x04, 0xD1);
   addPanasonicKey("aspect - zoom", Unmapped_Key, 0x80, 0x04, 0xDC);
   addPanasonicKey("aspect - full", Unmapped_Key, 0x80, 0x04, 0xDD);
+*/
   addPanasonicKey("ASPECT", AspectRatio_Key, 0x80, 0x04, 0xDE);
 }
 
@@ -272,6 +283,7 @@ void PanasonicTV1::populateInputList(
 {
   cb->clear();
 
+  cb->addItem("Antenna", QVariant(AntennaInput_Key));
   cb->addItem("Video 1", QVariant(VideoInput_Key));
   cb->addItem("Video 2", QVariant(Video2Input_Key));
   cb->addItem("Video 3", QVariant(Video3Input_Key));
