@@ -201,11 +201,16 @@ enum PIRKeyName
   Composite2Input_Key,
   SVideoInput_Key,
   SVideo2Input_Key,
+  VideoInput_Key,
+  Video2Input_Key,
+  Video3Input_Key,
+  Video4Input_Key,
   ComponentInput_Key,
   Component2Input_Key,
   HDMIInput_Key,
   HDMI2Input_Key,
   HDMI3Input_Key,
+  HDMI4Input_Key,
   ScartInput_Key,
   AuxInput_Key,
   MDInput_Key,
